@@ -7,16 +7,25 @@
 require_once("Console/Getopt.php");
 require_once("diogenes/diogenes.database-creator.inc.php");
 
+/** The DiogenesDbInit class handles database upgrades between 
+ *  Diogenes versions.
+ */
 class DiogenesDbInit extends DiogenesDatabaseCreator
 {
-  // database versions history
-  var $versions = array("0.9.9.3", "0.9.10", "0.9.12", "0.9.15", "0.9.16");
+  /** database versions history */
+  var $versions = array("0.9.9.3", "0.9.10", "0.9.12", "0.9.15", "0.9.16", "0.9.16+0.9.17pre15", "0.9.16+0.9.17pre19", "0.9.16+0.9.17pre21");
 
   /**
    * Upgrades the database from one version to the next
+   * 
+   * @param $newversion
    */
   function upgradeDb($newversion)
   {
+    // pre-upgrade master tables
+    $this->info("* Pre-upgrading master tables : diogenes_*");
+    $this->preupgradeMaster($newversion);
+  
     // upgrade barrels
     $res = $this->dbh->query("select alias from diogenes_site");
     while (list($alias) = mysql_fetch_row($res))
@@ -32,8 +41,31 @@ class DiogenesDbInit extends DiogenesDatabaseCreator
   }
 
   
-  /** upgrade a barrel's tables
+  /** Upgrades the master (i.e. common) tables before touching the barrel tables.
    *
+   * @param $newversion
+   */  
+  function preupgradeMaster($newversion)
+  {
+    switch($newversion) {
+    case "0.9.16+0.9.17pre15";
+      $this->info(" - adding 'barrel' field to 'diogenes_options' table");
+      $this->dbh->query("ALTER TABLE `diogenes_option` ADD `barrel` VARCHAR( 16 ) NOT NULL FIRST;");
+      $this->dbh->query(
+        "ALTER TABLE `diogenes_option` DROP PRIMARY KEY ,
+         ADD PRIMARY KEY ( `barrel` , `name` )");
+      break;
+      
+    default:
+      break;
+    }
+  }
+
+  
+  /** Upgrade a barrel's tables
+   *
+   * @param $alias
+   * @param $newversion
    */
   function upgradeBarrel($alias, $newversion)
   {
@@ -97,13 +129,40 @@ class DiogenesDbInit extends DiogenesDatabaseCreator
       $this->dbh->query("ALTER TABLE `{$alias}_menu` CHANGE `MIDpere` `MIDpere` INT( 10 ) UNSIGNED NOT NULL default '0'");
       $this->dbh->query("ALTER TABLE `{$alias}_menu` CHANGE `ordre` `ordre` INT( 10 ) UNSIGNED NOT NULL default '0'");
       break;
+
+    case "0.9.16+0.9.17pre15":
+      $this->info(" - merging '{$alias}_option' into 'diogenes_options'");
+      $res = $this->dbh->query("select name,value from `{$alias}_option`");
+      while (list($o_name,$o_value) = mysql_fetch_row($res)) 
+      {
+        $this->dbh->query("insert into `diogenes_option` set barrel='$alias',name='$o_name',value='".addslashes($o_value)."'");
+      }
+      mysql_free_result($res);
+      $this->info(" - dropping '{$alias}_option'");
+      $this->dbh->query("drop table `{$alias}_option`");
+
+      $this->info(" - adding 'parent' field to `{$alias}_page`");
+      $this->dbh->query("ALTER TABLE `{$alias}_page` ADD `parent` INT( 10 ) UNSIGNED NOT NULL default '0' AFTER `PID`");
+      $res = $this->dbh->query("select PID from `{$alias}_page` where location=''");
+      list($homepage) = mysql_fetch_row($res);
+      $this->dbh->query("update `{$alias}_page` set parent='$homepage' where location!=''");
+    
+      $this->info(" - ordering `{$alias}_page` entries by `location`");
+      $this->dbh->query("ALTER TABLE `{$alias}_page` CHANGE `location` `location` VARCHAR( 255 ) NOT NULL");
+      $this->dbh->query("ALTER TABLE `{$alias}_page` ORDER BY `location`");
+      break;
       
     default:
-#      $this->info(" - no changes needed.");
+      $this->info(" - no changes needed.");
       break;
     }
   }
 
+  
+  /** Upgrades the master (i.e. common) tables after the barrel tables have been updated.
+   *
+   * @param $newversion
+   */
   function upgradeMaster($newversion)
   {
     // upgrade master tables
@@ -128,6 +187,32 @@ class DiogenesDbInit extends DiogenesDatabaseCreator
       $this->dbh->query("ALTER TABLE `diogenes_perm` CHANGE `uid` `uid` INT(10) UNSIGNED NOT NULL default '0'");
       break;
       
+    case "0.9.16+0.9.17pre15":
+      $this->info(" - creating 'diogenes_plugin' table");
+      $this->dbh->query(
+        "CREATE TABLE `diogenes_plugin` (
+           `plugin` varchar(32) NOT NULL default '',
+           `barrel` varchar(16) NOT NULL default '',
+           `page` int(10) unsigned NOT NULL default '0',
+           `pos` int(10) unsigned NOT NULL default '0',
+           `params` text NOT NULL,
+            PRIMARY KEY  (`plugin`,`barrel`,`page`),
+            KEY `pos` (`pos`)
+          ) TYPE=MyISAM;");
+      break;
+
+    case "0.9.16+0.9.17pre19":
+      $this->info(" - changing id of `diogenes_logsessions` to INT(10) UNSIGNED");
+      $this->dbh->query("ALTER TABLE `diogenes_logsessions` CHANGE `id` `id` INT( 10 ) UNSIGNED NOT NULL AUTO_INCREMENT");
+      break;
+     
+    case "0.9.16+0.9.17pre21":      
+      $this->dbh->query("INSERT INTO diogenes_logactions VALUES (13, 'barrel_options', 'the barrel options were updated');");
+      $this->dbh->query("INSERT INTO diogenes_logactions VALUES (14, 'barrel_plugins', 'the barrel plugins were modified');");
+      $this->dbh->query("INSERT INTO diogenes_logactions VALUES (15, 'page_props', 'the page properties were updated');");
+      $this->dbh->query("INSERT INTO diogenes_logactions VALUES (16, 'page_plugins', 'the page plugins were modified');");
+      break;
+
     default:
       $this->info(" - no changes needed.");
       break;
