@@ -1,7 +1,7 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.toplevel.inc.php';
-require_once 'diogenes.table-editor.inc.php';
+require_once 'diogenes/diogenes.table-editor.inc.php';
 
 $page = new $globals->toplevel(true);
 $page->assign('greeting',__("User accounts"));
