@@ -1,8 +1,10 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.admin.inc.php';
+require_once 'Barrel/Page.php';
+require_once 'Barrel/File.php';
 
-if (!isset($_REQUEST['dir']) && !isset($_REQUEST['file']))
+if (empty($_REQUEST['dir']) && empty($_REQUEST['file']))
   exit;
 
 // retrieve directory & file info
@@ -10,16 +12,16 @@ $dir = $_REQUEST["dir"];
 $file = $_REQUEST["file"];
 $page = new DiogenesAdmin($dir);
 
-$res = $globals->db->query("select location from {$page->table_page} where PID='$dir'");
-if (!list($dirloc) = mysql_fetch_row($res))
-  $page->kill(__("Directory not found"));
+$bbarrel = $page->barrel;
+$bpage = Diogenes_Barrel_Page::fromDb($bbarrel, $dir);
+$bfile = new Diogenes_Barrel_File($bpage, $file);
 
 // rcs handle
 $rcs = $page->getRcs();
 
 // file location & url
-$mydir = $page->spool->spoolPath($dir);
-$myfile = $page->spool->spoolPath($dir,$file);
+$mydir = $bbarrel->spool->spoolPath($dir);
+$myfile = $bbarrel->spool->spoolPath($dir,$file);
 
 // process requested action
 $action = isset($_REQUEST["action"]) ? $_REQUEST["action"] : "";
@@ -38,7 +40,7 @@ case "update":
 
 $rev = array_shift($rcs->logParse($dir,$file));
 
-$page->assign('greeting', __("File editor")." - $dirloc/$file - {$rev['rev']}");
+$page->assign('greeting', __("File editor")." - ". $bpage->getLocation($file). " - {$rev['rev']}");
 $page->assign('post',$page->script_self());
 $page->assign('dir',$dir);
 $page->assign('file',$file);
@@ -46,16 +48,9 @@ $page->assign('source',__("File source"));
 $page->assign('msg_log',__("log message"));
 $page->assign('file_content',htmlspecialchars(file_get_contents($myfile), ENT_NOQUOTES));
 $page->assign('submit',__("Submit"));
-$page->toolbar(__("Page"), array (
-  array( __("pages catalog"), "pages"),
-  array( __("page properties"), "pages?PID=$dir" ),
-  array( __("view page"), $page->urlSite($dirloc ? "$dirloc/" : "")),
-  array( __("browse files"), "files?dir=$dir" )
-));
-$page->toolbar(__("File"), array (
-  array( __("raw editor") ),
-  array( __("HTML editor"), "compose?dir=$dir&amp;file=$file" ),
-  array( __("file revisions"), "files?action=revs&amp;dir=$dir&amp;target=$file" )
-));
+
+// top toolbar
+$page->toolbar(__("Page"), $bpage->make_toolbar());
+$page->toolbar(__("File"), $bfile->make_toolbar(true));
 $page->display('admin-edit.tpl');
 ?>
