@@ -3,6 +3,7 @@ require_once 'diogenes.common.inc.php';
 require_once 'diogenes.admin.inc.php';
 
 $page = new DiogenesAdmin;
+$bbarrel =& $page->barrel;
 
 // the id of the parent menu
 $MIDpere = isset($_REQUEST['MIDpere']) ? $_REQUEST['MIDpere'] : 0;
@@ -40,20 +41,20 @@ switch ($action) {
 /* we want to erase the current entry */
 case "supprimer":
   $MID = $_REQUEST['MID'];
-  if (mysql_num_rows($globals->db->query("SELECT MID FROM {$page->table_menu} WHERE MIDpere=$MID")) > 0) {
+  if (mysql_num_rows($globals->db->query("SELECT MID FROM {$bbarrel->table_menu} WHERE MIDpere=$MID")) > 0) {
     $page->info(__("The selected menu has child items, please remove them first."));
     break;
   }
 
   /* erase the current entry */
-  $globals->db->query("DELETE FROM {$page->table_menu} WHERE MID=$MID");
+  $globals->db->query("DELETE FROM {$bbarrel->table_menu} WHERE MID=$MID");
 
   /* renumber the other menu entries so that they are between 1 and the number of entries */
-  $res = $globals->db->query("SELECT MID FROM {$page->table_menu} WHERE MIDpere=$MIDpere ORDER BY ordre");
+  $res = $globals->db->query("SELECT MID FROM {$bbarrel->table_menu} WHERE MIDpere=$MIDpere ORDER BY ordre");
   $i = 0;
   while (list($MIDtoorder) = mysql_fetch_array($res)) {
     $i++;
-    $globals->db->query("UPDATE {$page->table_menu} SET ordre=$i WHERE MID=$MIDtoorder");
+    $globals->db->query("UPDATE {$bbarrel->table_menu} SET ordre=$i WHERE MID=$MIDtoorder");
   }
   mysql_free_result($res);
   break;
@@ -61,13 +62,13 @@ case "supprimer":
 /* bring an entry up in the menu */
 case "remonter":
   $ordre = $_REQUEST['ordre'];
-  swapentries($MIDpere,$ordre-1,$ordre,$page->table_menu);
+  swapentries($MIDpere,$ordre-1,$ordre,$bbarrel->table_menu);
   break;
 
 /* push an entry down in the menu */
 case "descendre":
   $ordre = $_REQUEST['ordre'];
-  swapentries($MIDpere,$ordre,$ordre+1,$page->table_menu);
+  swapentries($MIDpere,$ordre,$ordre+1,$bbarrel->table_menu);
   break;
 
 /* create or update a menu entry */
@@ -89,13 +90,13 @@ case "modifier":
     $MID = $_REQUEST['MID'];
     $title = $_REQUEST['title'];
     if ($MID == 0) {
-      $res=$globals->db->query("SELECT MAX(ordre) from {$page->table_menu} where MIDpere=$MIDpere");
+      $res=$globals->db->query("SELECT MAX(ordre) from {$bbarrel->table_menu} where MIDpere=$MIDpere");
       list($ordre) = mysql_fetch_row($res);
       $ordre++;
-      $globals->db->query("INSERT INTO {$page->table_menu} SET MIDpere='$MIDpere',ordre='$ordre',title='$title',link='$link',pid='$pid'");
+      $globals->db->query("INSERT INTO {$bbarrel->table_menu} SET MIDpere='$MIDpere',ordre='$ordre',title='$title',link='$link',pid='$pid'");
       $MID = mysql_insert_id();
     } else {
-      $globals->db->query("UPDATE {$page->table_menu} SET title='$title',link='$link',pid='$pid' WHERE MID=$MID");
+      $globals->db->query("UPDATE {$bbarrel->table_menu} SET title='$title',link='$link',pid='$pid' WHERE MID=$MID");
     }
 
     break;
@@ -110,7 +111,7 @@ case "editer":
 
   // if this is an existing entry, retrieve data
   if ($MID) {
-    $res = $globals->db->query("SELECT link,title,pid FROM {$page->table_menu} WHERE MID=$MID");
+    $res = $globals->db->query("SELECT link,title,pid FROM {$bbarrel->table_menu} WHERE MID=$MID");
     list($link, $title, $pid) = mysql_fetch_row($res);
     mysql_free_result($res);
   }
@@ -131,8 +132,20 @@ case "editer":
   $page->assign('SEvaleur', $link ? $link : "http://");
   $page->assign('page_sel',$pid);
 
-  $res = $globals->db->query("SELECT PID,title from {$page->table_page} ORDER BY title");
+  // retrieve all the barrel's pages
+  $fpages = $bbarrel->getPages();
+  $page_opts = array();
+  foreach($fpages as $pkey => $ppage)
+  {
+    $pageloc = $bbarrel->getLocation($pkey);
+    $page_opts[$pkey] = ( strlen($pageloc) ? "<$pageloc> " : "") . $ppage->props['title'];
+  }
+  $page->assign('page_opts', $page_opts);
+
+  $res = $globals->db->query("SELECT PID,title from {$bbarrel->table_page} ORDER BY title");
   while (list($myPID,$myTITLE) = mysql_fetch_row($res)) {
+    //$pageloc = $bbarrel->getLocation($pkey);
+    //$page_opts[$pkey] = ( strlen($pageloc) ? "<$pageloc> " : "") . $ppage->props['title'];  
     $page->append('page_values',$myPID);
     $page->append('page_names',stripslashes($myTITLE));
   }
@@ -155,16 +168,15 @@ case "editer":
 }
 
 // get the maximum order
-$res=$globals->db->query("SELECT MAX(ordre) from {$page->table_menu} where MIDpere=$MIDpere");
+$res=$globals->db->query("SELECT MAX(ordre) from {$bbarrel->table_menu} where MIDpere=$MIDpere");
 list($maxOrdre)=mysql_fetch_row($res);
 mysql_free_result($res);
 
 // retrieve the entries
 $res = $globals->db->query("SELECT m.MID,m.ordre,m.title,m.link,m.PID,p.title ".
-                       "from {$page->table_menu} as m ".
-                       "left join {$page->table_page} as p on m.PID=p.PID ".
+                       "from {$bbarrel->table_menu} as m ".
+                       "left join {$bbarrel->table_page} as p on m.PID=p.PID ".
                        "where MIDpere=$MIDpere order by ordre");
-$odd = false;
 while (list($MID,$ordre,$title,$link,$PID,$ptitle) = mysql_fetch_row($res)) {
   $clickup="?action=remonter&amp;MIDpere=$MIDpere&amp;ordre=$ordre";
   $clickdown="?action=descendre&amp;MIDpere=$MIDpere&amp;ordre=$ordre";
@@ -180,7 +192,7 @@ while (list($MID,$ordre,$title,$link,$PID,$ptitle) = mysql_fetch_row($res)) {
   
   // describe the current link
   if ($PID) {
-    $descr = "<a href=\"pages?PID=$PID\">$ptitle</a>";
+    $descr = "<a href=\"pages?dir=$PID\">$ptitle</a>";
   } elseif ($link) {
     $descr = "<a href=\"$link\">[ext] $link</a>";
   } else {
@@ -189,10 +201,9 @@ while (list($MID,$ordre,$title,$link,$PID,$ptitle) = mysql_fetch_row($res)) {
 
   // smarty assignments
   $page->append('entries',
-          array($odd ? 'odd' : 'even', $MID, array(stripslashes($title), "?MIDpere=$MID"),
+          array($MID, array(stripslashes($title), "?MIDpere=$MID"),
           stripslashes($descr),
           $edit,$del,$up,$down));
-  $odd = !$odd;
 }
 mysql_free_result($res);
 
@@ -202,7 +213,7 @@ foreach($filiation as $mykey=>$myval) {
   if ($myval == 0) {
     $blab = "<i>home</i>";
   } else {
-    $res = $globals->db->query("SELECT title FROM {$page->table_menu} WHERE MID='$myval'");
+    $res = $globals->db->query("SELECT title FROM {$bbarrel->table_menu} WHERE MID='$myval'");
     list($blab) = mysql_fetch_row($res);
     $blab = stripslashes($blab);
     mysql_free_result($res);
