@@ -46,19 +46,23 @@ class DiogenesCvs extends DiogenesRcs {
     // the pserver suicides after 5mn of inactivity
     $this->cvsopt = "-d :pserver:{$this->login}@localhost:{$this->port}{$globals->rcsroot}";
     putenv("CVS_PASSFILE={$globals->spoolroot}/.cvspass");
-    if ($fp = popen("perl {$globals->root}/cvs.pl -p {$this->port} -r {$globals->rcsroot} -f -m -s 300","r"))
+    if ($fp = popen(escapeshellcmd("perl ".escapeshellarg("{$globals->root}/cvs.pl")." -p ".escapeshellarg($this->port)." -r ".escapeshellarg($globals->rcsroot)." -f -m -s 300"),"r"))
       pclose($fp);
 
     // if asked to, do checkout of the module
     if ($init) {
       chdir($globals->spoolroot);
-      exec("cvs {$this->cvsopt} co ".escapeshellarg($alias));
+      if ($this->cmdExec("cvs {$this->cvsopt} co ".escapeshellarg($alias))) 
+      {    
+        $this->info($this->cmdStatus());    
+        $this->kill("CVS : Error, checking out CVS module '$alias' failed!");
+      }
     }
 
     // check we have a correct checkout
     if ( !is_dir($this->spoolPath("CVS"))
       || !is_writable($this->spoolPath("CVS")) )
-      $this->kill("Checkout for CVS module '$alias' is invalid!");
+      $this->kill("CVS : Error, checkout for CVS module '$alias' is invalid!");
 
   }
 
@@ -93,7 +97,7 @@ class DiogenesCvs extends DiogenesRcs {
     // check directories
     if (!$this->checkDir($dir)) {
         // error
-        $this->info("Error: CVS sanity check for '$dir' failed!");
+        $this->info("CVS : Error, sanity check for '$dir' failed!");
         return false;
     }
 
@@ -106,7 +110,7 @@ class DiogenesCvs extends DiogenesRcs {
 
     $fp = fopen($sfile,"w");
     if (!$fp) {
-      $this->info("Error: could not open spool file for writing!");
+      $this->info("CVS : Error, could not open spool file '$sfile' for writing!");
       return false;
     }
     fwrite($fp,$content);
@@ -116,18 +120,18 @@ class DiogenesCvs extends DiogenesRcs {
 
     // if the RCS file does not exist, do a cvs add
     if (!file_exists($rfile)) {
-      exec("cvs {$this->cvsopt} add ".escapeshellarg($file),$ret);
-      if ($ret) {
+      if ($this->cmdExec("cvs {$this->cvsopt} add ".escapeshellarg($file))) {
         // error
         $this->info("Error: could not do CVS add!");
+        $this->info($this->cmdStatus());
         return false;
       }
     } else {
       // do an update to make sure we are up to date
-      exec("cvs {$this->cvsopt} up ".escapeshellarg($file),$ret);
+      $this->cmdExec("cvs {$this->cvsopt} up ".escapeshellarg($file));
     }
 
-    exec("cvs {$this->cvsopt} commit -m".escapeshellarg($message)." ".escapeshellarg($file),$ret);
+    $this->cmdExec("cvs {$this->cvsopt} commit -m".escapeshellarg($message)." ".escapeshellarg($file));
 
     return true;
   }
@@ -143,10 +147,10 @@ class DiogenesCvs extends DiogenesRcs {
   function diff($dir,$file,$r1,$r2)
   {
     chdir($this->spoolPath($dir));
-    $this->info("CVS : diffing $file ($r1 to $r2)..");
+    $this->info("CVS : diffing '$file' ($r1 to $r2)..");
 
-    return shell_exec("cvs {$this->cvsopt} diff  -r".escapeshellarg($r1).
-      " -r".escapeshellarg($r2)." ".escapeshellarg($file));
+    $this->cmdExec("cvs {$this->cvsopt} diff  -r".escapeshellarg($r1)." -r".escapeshellarg($r2)." ".escapeshellarg($file));
+    return $this->cmd_output;
   }
 
 
@@ -157,7 +161,8 @@ class DiogenesCvs extends DiogenesRcs {
   */
   function logEntries($dir,$file) {
     chdir($this->spoolPath($dir));
-    return shell_exec("cvs {$this->cvsopt} log ".escapeshellarg($file));
+    $this->cmdExec("cvs {$this->cvsopt} log ".escapeshellarg($file));
+    return $this->cmd_output;
   }
 
 
@@ -173,8 +178,8 @@ class DiogenesCvs extends DiogenesRcs {
 
     @mkdir($this->spoolPath($parent,$dir),0700);
     chdir($this->spoolPath($parent));
-    exec("cvs {$this->cvsopt} add ".escapeshellarg($dir),$ret);
-      return $ret;
+    $ret = $this->cmdExec("cvs {$this->cvsopt} add ".escapeshellarg($dir));
+    return $ret;
   }
 
 }
