@@ -27,6 +27,15 @@ class DiogenesSpool {
   /** Absolute directory location for the barrel's spool. */
   var $datadir;
 
+  /** The last command that was executed. */
+  var $cmd_call;
+  
+  /** The output of the last command that was executed. */
+  var $cmd_output;
+  
+  /** The return value of the last command. */
+  var $cmd_return;
+  
   /** The caller. It needs to define the 3 following methods :
    * 
    * @see info, kill, log
@@ -45,7 +54,38 @@ class DiogenesSpool {
     $this->alias = $alias;
   }
 
+  
+  /** Execute a shell command and store information about it.
+   *
+   * @param $cmd the command to execute
+   */
+  function cmdExec($cmd)
+  {
+    $this->cmd_call = $cmd;    
+    unset($this->cmd_output);
+    unset($this->cmd_return);
+    
+    exec(escapeshellcmd($cmd), $this->cmd_output, $this->cmd_return);
+    
+    return $this->cmd_return;
+  }
+  
+  
+  /** Return information about the last command that was executed.
+   */
+  function cmdStatus()
+  {
+    $out  =
+     "-- [ command information ] -- \n".
+     "command : {$this->cmd_call}\n".
+     "return value : {$this->cmd_return}\n".
+     "-- [ command output ] --\n".
+     implode("\n", $this->cmd_output)."\n".
+     "--";
+   return $out;
+  }
 
+  
   /** Report an information.
    *
    * @param msg
@@ -82,7 +122,7 @@ class DiogenesSpool {
    */
   function checkPath($parent,$entry,$fatal = true) {
     $ret = preg_match("/^([a-zA-Z0-9\-_]+[\.,\/]?)*$/",$parent)
-        && preg_match("/^([a-zA-Z0-9\-_]+[\.,]?)*$/",$entry);
+        && preg_match("/^([a-zA-Z0-9\-_]+[\., ]?)*$/",$entry);
 
     if (!$ret && $fatal)
       $this->kill("malformed path ('$parent','$entry')");
